Welcome to ClientVPS Mirrors

Help for package ucie
Type: Package
Title: Mapping 3D Data into CIELab Color Space
Version: 1.0.2
Maintainer: Mikaela Koutrouli <mikaela.koutrouli@cpr.ku.dk>
Description: Returns a data frame with the names of the input data points and hex colors (or CIELab coordinates). Data can be mapped to colors for use in data visualization. It optimally maps data points into a polygon that represents the CIELab colour space. Since Euclidean distance approximates relative perceptual differences in CIELab color space, the result is a color encoding that aims to capture much of the structure of the original data.
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.1.2
Imports: colorspace, dplyr, geometry, pracma, ptinpoly, rgl, remotes
Suggests: testthat (≥ 3.0.0)
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2022-06-20 19:28:49 UTC; tgn531
Author: Mikaela Koutrouli [aut, cre], Lars Juhl Jensen [aut]
Repository: CRAN
Date/Publication: 2022-06-20 19:40:02 UTC

Mapping 3D Data into CIELab Color Space

Description

Returns a data frame with the names of the input data points and hex colors (or CIELab coordinates). Data can be mapped to colors for use in data visualization. It optimally maps data points into a polygon that represents the CIELab colour space. Since Euclidean distance approximates relative perceptual differences in CIELab color space, the result is a color encoding that aims to capture much of the structure of the original data.

Usage

data2cielab(dataset, WL = 1, Wa = 1, Wb = 1, S = 1, LAB_coordinates = FALSE)
Parameters(dataset, WL = 1, Wa = 1, Wb = 1)
ProduceColors(dataset, Soptim, RotL, Rota, Rotb, TrL, Tra, Trb,
              WL = 1, Wa = 1, Wb = 1, S = 1, LAB_coordinates = FALSE)

Arguments

dataset

3-column dataset to be translated into colors.

WL

Weight of L* axis in optimization function. Default value 1.

Wa

Weight of a* axis in optimization function. Default value 1.

Wb

Weight of b* axis in optimization function. Default value 1.

S

Scaling factor for color mapping. Default value 1.

LAB_coordinates

Logical. If FALSE, the function returns a data frame with hex colors. If TRUE, the function returns a data frame with the L*a*b* coordinates. Default value FALSE.

Soptim

A value for the size of the cloud.

RotL

A value for the rotation of the cloud in the L axis.

Rota

A value for the rotation of the cloud in the a axis.

Rotb

A value for the rotation of the cloud in the b axis.

TrL

A value for the translation of the cloud in the L axis.

Tra

A value for the translation of the cloud in the a axis.

Trb

A value for the translation of the cloud in the b axis.

Value

None

Examples


  df <- data.frame(V1=runif(10,  0,1), V2=runif(10,  0,5), V3=runif(10,  0,30))
  data_with_colors <- data2cielab(df, Wb=1.2, S=1.6)
  data_with_colors <- data2cielab(df, LAB_coordinates = TRUE)

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.